# Exclude plugin .so from provides.
%global __provides_exclude_from ^%{_libdir}/%{name}/(plugins|views)/.*\\.so$

# Needed if/when system lua is not compatible with current darktable.
%bcond_without systemlua

Name:           darktable
Version:        3.8.0
Release:        %mkrel 1
Summary:        Open source photography workflow application and RAW developer
Group:          Graphics/Photography
License:        GPLv3+
Url:            https://www.darktable.org
Source0:        https://github.com/darktable-org/darktable/releases/download/release-%{version}/%{name}-%{version}.tar.xz
Patch1:         0001-Define-__DT_CLONE_TARGETS__-on-aarch64.patch

BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  gnome-doc-utils
BuildRequires:  intltool
BuildRequires:  libgomp-devel
BuildRequires:  perl-Image-ExifTool
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(colord-gtk)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(flickcurl)
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(libheif)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(osmgpsmap-1.0)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  xsltproc

%if 0%{?with systemlua}
BuildRequires:  lua-devel
%else
Provides:       bundled(lua) = 5.4.3
%endif

# Only supports 64-bit architectures.
ExclusiveArch:  x86_64 aarch64

Requires:       perl-Image-ExifTool

%description
Darktable is an open source photography workflow application and
RAW developer. A virtual lighttable and darkroom for photographers.
It manages your digital negatives in a database, lets you view them
through a zoomable lighttable and enables you to develop raw images
and enhance them.

%prep
%autosetup -p1

%build
%cmake \
  -DBINARY_PACKAGE_BUILD=ON \
  -DDONT_USE_INTERNAL_LUA=0%{?with_systemlua}
%cmake_build

%install
%cmake_install

# Handle docs in files section.
rm -rf %{buildroot}%{_docdir}

# To find libdarktable.so without rpath.
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf << EOF
%{_libdir}/%{name}
EOF

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS README.md RELEASE_NOTES.md
%license LICENSE
%config %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_bindir}/%{name}
%{_bindir}/%{name}-chart
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-cltest
%{_bindir}/%{name}-cmstest
%{_bindir}/%{name}-generate-cache
%{_bindir}/%{name}-rs-identify
%{_datadir}/applications/%{name}.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/%{name}*
%{_libdir}/%{name}/
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/%{name}-cli.1.*
%{_mandir}/man1/%{name}-cltest.1.*
%{_mandir}/man1/%{name}-cmstest.1.*
%{_mandir}/man1/%{name}-generate-cache.1.*


%changelog
* Sun Jan 23 2022 akien <akien> 3.8.0-1.mga8
+ Revision: 1769516
- Version 3.8.0
- Add HEIF support
- Require exiftool
- Version 3.6.1
- Fix potential crash reported upstream (GH-9410)
- Version 3.6.0
- Version 3.4.1 (mga#28741)

* Sun Dec 27 2020 akien <akien> 3.4.0-1.mga8
+ Revision: 1664254
- Fix build without SSE2
- Version 3.4.0

* Sat Sep 26 2020 tv <tv> 3.2.1-2.mga8
+ Revision: 1630187
- rebuild for new libIlmImf

* Mon Aug 24 2020 neoclust <neoclust> 3.2.1-1.mga8
+ Revision: 1618380
- New version 3.2.1

* Sat Apr 18 2020 daviddavid <daviddavid> 3.0.2-1.mga8
+ Revision: 1568645
- new version: 3.0.2

* Tue Feb 18 2020 umeabot <umeabot> 3.0.0-2.mga8
+ Revision: 1541570
- Mageia 8 Mass Rebuild

* Mon Dec 30 2019 akien <akien> 3.0.0-1.mga8
+ Revision: 1474920
- Version 3.0.0 dropped 32-bit support (disable i586)
- arm64v8 seems supported (enable aarch64)
+ wally <wally>
- build with new cmake macros
+ daviddavid <daviddavid>
- new version: 3.0.0

* Mon Oct 21 2019 daviddavid <daviddavid> 2.6.3-1.mga8
+ Revision: 1454841
- new version: 2.6.3

* Thu May 16 2019 daviddavid <daviddavid> 2.6.2-2.mga7
+ Revision: 1398046
- rebuild for new exiv2 0.27.1

* Tue Apr 02 2019 daviddavid <daviddavid> 2.6.2-1.mga7
+ Revision: 1385053
- new version: 2.6.2

* Sat Dec 29 2018 luigiwalser <luigiwalser> 2.6.0-2.mga7
+ Revision: 1346040
- rebuild for exiv2

* Fri Dec 28 2018 akien <akien> 2.6.0-1.mga7
+ Revision: 1345622
- Version 2.6.0

* Mon Oct 15 2018 daviddavid <daviddavid> 2.4.4-3.mga7
+ Revision: 1320593
- rebuild for new ilmbase and openexr 2.3.0

* Sun Sep 23 2018 umeabot <umeabot> 2.4.4-2.mga7
+ Revision: 1297401
- Mageia 7 Mass Rebuild

* Wed Jun 06 2018 akien <akien> 2.4.4-1.mga7
+ Revision: 1234986
- Version 2.4.4

* Sun May 27 2018 wally <wally> 2.4.3-2.mga7
+ Revision: 1232410
- rebuild for openexr 2.2.1

* Mon May 14 2018 akien <akien> 2.4.3-1.mga7
+ Revision: 1229326
- Version 2.4.3

* Sat Jan 13 2018 wally <wally> 2.4.0-2.mga7
+ Revision: 1192559
- rebuild for new ilmbase

* Fri Dec 29 2017 akien <akien> 2.4.0-1.mga7
+ Revision: 1187026
- Version 2.4.0

* Tue Aug 08 2017 daviddavid <daviddavid> 2.2.5-3.mga7
+ Revision: 1138931
- rebuild for new libwebp 0.6.0

* Tue Jun 20 2017 neoclust <neoclust> 2.2.5-2.mga6
+ Revision: 1107991
- Rebuild against new exiv2

* Fri Jun 02 2017 akien <akien> 2.2.5-1.mga6
+ Revision: 1105842
- Version 2.2.5

* Fri Apr 07 2017 akien <akien> 2.2.4-1.mga6
+ Revision: 1096068
- Version 2.2.4

* Mon Jan 30 2017 akien <akien> 2.2.2-1.mga6
+ Revision: 1084289
- Version 2.2.2

* Thu Jan 05 2017 akien <akien> 2.2.1-1.mga6
+ Revision: 1080259
- Version 2.2.1

* Wed Dec 28 2016 akien <akien> 2.2.0-1.mga6
+ Revision: 1078464
- Version 2.2.0

* Sat Nov 12 2016 akien <akien> 2.0.7-1.mga6
+ Revision: 1066683
- Version 2.0.7

* Wed Sep 14 2016 akien <akien> 2.0.6-1.mga6
+ Revision: 1052973
- Version 2.0.6

* Thu Aug 11 2016 akien <akien> 2.0.5-1.mga6
+ Revision: 1045735
- Version 2.0.5

* Tue Jul 12 2016 pterjan <pterjan> 2.0.4-2.mga6
+ Revision: 1041207
- Restrict arches as it requires SSE

* Tue May 10 2016 akien <akien> 2.0.4-1.mga6
+ Revision: 1012280
- Version 2.0.4

* Sun May 01 2016 akien <akien> 2.0.3-2.mga6
+ Revision: 1008465
- Drop broken desktop keywords
- Version 2.0.3

* Mon Feb 08 2016 akien <akien> 2.0.1-1.mga6
+ Revision: 949496
- Version 2.0.1

* Fri Jan 08 2016 luigiwalser <luigiwalser> 2.0.0-4.mga6
+ Revision: 920534
- rebuild for lensfun

* Sun Jan 03 2016 luigiwalser <luigiwalser> 2.0.0-3.mga6
+ Revision: 918986
- rebuild for osm-gps-map

* Sat Jan 02 2016 luigiwalser <luigiwalser> 2.0.0-2.mga6
+ Revision: 918197
- rebuild for libwebp

* Wed Dec 30 2015 guillomovitch <guillomovitch> 2.0.0-1.mga6
+ Revision: 916987
- new version 2.0.0

* Mon Nov 30 2015 akien <akien> 1.6.9-1.mga6
+ Revision: 907406
- Version 1.6.9

* Wed Aug 26 2015 fwang <fwang> 1.6.8-2.mga6
+ Revision: 869469
- rebuild for glew

* Mon Aug 03 2015 guillomovitch <guillomovitch> 1.6.8-1.mga6
+ Revision: 860932
- new version 1.6.8

* Mon Jun 22 2015 akien <akien> 1.6.7-1.mga6
+ Revision: 839484
- Version 1.6.7

* Tue May 12 2015 akien <akien> 1.6.6-1.mga5
+ Revision: 821938
- Version 1.6.6
- Simplify package description
- Add patch for security vulnerability in libraw (mga#15915)

* Sun Mar 08 2015 akien <akien> 1.6.3-1.mga5
+ Revision: 818184
- Version 1.6.3

* Sun Feb 22 2015 anaselli <anaselli> 1.6.2-2.mga5
+ Revision: 816400
- rebuilt for new libgphoto2

* Tue Feb 03 2015 akien <akien> 1.6.2-1.mga5
+ Revision: 813241
- Version 1.6.2

* Fri Jan 09 2015 akien <akien> 1.6.1-1.mga5
+ Revision: 809629
- Version 1.6.1
- Build against OpenMP for additional threading support

* Sun Dec 14 2014 akien <akien> 1.6.0-1.mga5
+ Revision: 802967
- Version 1.6.0

* Wed Oct 15 2014 umeabot <umeabot> 1.4.2-7.mga5
+ Revision: 748549
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.4.2-6.mga5
+ Revision: 693726
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.4.2-5.mga5
+ Revision: 678671
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.4.2-4.mga5
+ Revision: 666987
- rebuild for ilmbase and OpenEXR

* Tue Jun 24 2014 barjac <barjac> 1.4.2-3.mga5
+ Revision: 639287
- add -DBINARY_PACKAGE_BUILD=On to maybe fix mga#12510
- replace %%make
- fix tabs/spaces
- Correct summary
- Correct capitalization and punctuation in description
- Change form of one BR to satisfy rpmlint

* Mon Jun 23 2014 doktor5000 <doktor5000> 1.4.2-2.mga5
+ Revision: 639040
- do not use parallel make, try to fix (mga#12510)

* Sun May 04 2014 akien <akien> 1.4.2-1.mga5
+ Revision: 619975
- Version 1.4.2

* Thu May 01 2014 luigiwalser <luigiwalser> 1.4.1-2.mga5
+ Revision: 619149
- rebuild for ilmbase

* Sat Feb 15 2014 dams <dams> 1.4.1-1.mga5
+ Revision: 592407
- new version 1.4.1

* Mon Feb 10 2014 dams <dams> 1.4-2.mga5
+ Revision: 588969
- rebuild for new exiv2

* Tue Feb 04 2014 dams <dams> 1.4-1.mga5
+ Revision: 581091
- clean specfile

* Thu Jan 30 2014 petos <petos> 1.4-1.mga4
+ Revision: 568561
- New version -  1.4

* Sat Oct 19 2013 umeabot <umeabot> 1.2.3-4.mga4
+ Revision: 534824
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 wally <wally> 1.2.3-3.mga4
+ Revision: 478963
- rebuild for new colord

* Sat Sep 14 2013 wally <wally> 1.2.3-2.mga4
+ Revision: 478784
- add ld.so.conf file to help locating needed private lib (mga#11228)
- exclude plugin .so from provides
- build with system osm-gps-map
- rediff glibdir patch to apply with %%apply_patches
- handle docs in files section

* Fri Sep 13 2013 dams <dams> 1.2.3-1.mga4
+ Revision: 478568
- new version 1.2.3
+ fwang <fwang>
- br GraphicsMagick

* Thu Sep 12 2013 fwang <fwang> 1.2.2-3.mga4
+ Revision: 477878
- use cmake macro

* Thu Sep 12 2013 fwang <fwang> 1.2.2-2.mga4
+ Revision: 477862
- rebuild for new openexr

* Fri Jun 28 2013 dams <dams> 1.2.2-1.mga4
+ Revision: 447882
- new version 1.2.2

* Mon Jun 03 2013 fwang <fwang> 1.2.1-2.mga4
+ Revision: 435818
- fix br
- rebuild for new libpng

* Tue May 28 2013 dams <dams> 1.2.1-1.mga4
+ Revision: 429035
- new version 1.2.1

* Mon Apr 08 2013 dams <dams> 1.2-1.mga3
+ Revision: 409074
- new version 1.2

* Wed Mar 27 2013 dams <dams> 1.1.4-1.mga3
+ Revision: 405752
- new version 1.1.4

* Fri Mar 08 2013 dams <dams> 1.1.3-1.mga3
+ Revision: 401787
- new version 1.1.3
- Fix BuildRequires to build 'darktable-viewer' (add 'SDL-devel')
- Add 'colord-devel' as a BuildRequires to remove warning during build

* Fri Jan 11 2013 umeabot <umeabot> 1.1.1-2.mga3
+ Revision: 348612
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 petos <petos> 1.1.1-1.mga3
+ Revision: 330355
- New version of Darktable. Lot of bugfixes...

* Sun Dec 02 2012 petos <petos> 1.1-1.mga3
+ Revision: 325634
- br OpenEXR
- Update to new version 1.1

* Sun Dec 02 2012 fwang <fwang> 1.0.5-6.mga3
+ Revision: 324978
- br openexr
- rebuild for new ilmbase
+ dams <dams>
- update %%Group with new policy

* Mon Aug 27 2012 petos <petos> 1.0.5-4.mga3
+ Revision: 284557
- update br
- update rel
- update
- Updated message
- Typo fixed
- Reverted fwang's changes -- breaking package in 64bit system

* Sun Aug 05 2012 fwang <fwang> 1.0.5-3.mga3
+ Revision: 278929
- use system cmake macro

* Sun Aug 05 2012 fwang <fwang> 1.0.5-2.mga3
+ Revision: 278924
- rebuild for new gphoto

* Tue Jul 24 2012 petos <petos> 1.0.5-1.mga3
+ Revision: 274111
- Updated to new version

* Sun Jun 24 2012 petos <petos> 1.0.4-4.mga3
+ Revision: 263307
- fixed build
- Removed malfunctioned patch

* Tue Jun 19 2012 petos <petos> 1.0.4-3.mga3
+ Revision: 262012
- New buildrequires flickcurl-devel
- New buildRequire

* Mon Jun 18 2012 fwang <fwang> 1.0.4-2.mga3
+ Revision: 261637
- find correct path in lib64
- add more br
- br exiv
- cleanup spec

* Thu Jun 07 2012 petos <petos> 1.0.4-1.mga3
+ Revision: 257147
- Updated to new version

* Fri May 11 2012 dams <dams> 1.0.3-1.mga2
+ Revision: 235255
- new version 1.0.3

* Sun Apr 15 2012 petos <petos> 1.0-1.mga2
+ Revision: 230874
- imported package darktable

